@@ -2,7 +2,6 @@ import abc, argparse, contextlib, datetime, itertools, logging, os, pathlib, ran
 if sys.platform != "cygwin":
   import psutil
 
-logging.basicConfig()
 logger = logging.getLogger("JobLock")
 logger.setLevel(logging.INFO)
 
@@ -218,7 +217,6 @@ batchsubmissionsystems = [slurm, condor]
 
 setsqueueoutput = slurm.setjoblistoutput
 setcondorqoutput = condor.setjoblistoutput
-SLURM_JOBID = slurm.SLURM_JOBID
 
 def jobinfo():
   for system in batchsubmissionsystems:
@@ -229,7 +227,7 @@ def jobinfo():
   return sys.platform, cpuid(), os.getpid()
 
 class JobLock(object):
-  defaultcorruptfiletimeout = datetime.timedelta(hours=24)
+  defaultcorruptfiletimeout = datetime.timedelta(hours=1)
 
   def __init__(self, filename, *, outputfiles=[], checkoutputfiles=True, inputfiles=[], checkinputfiles=True, prevsteplockfiles=[], corruptfiletimeout=None, mkdir=False, dosqueue=True, cachesqueue=True, suppressfileopenfailure=False):
     self.filename = pathlib.Path(filename)
@@ -372,23 +370,38 @@ class JobLock(object):
       #a race condition: two jobs could be looking if the previous
       #job failed at the same time, and one of them could remove
       #the lock created by the other one
-      with JobLock(self.iterative_lock_filename, **self.sublockkwargs) as iterative_lock:
-        self.__iterative_lock = iterative_lock
-        if not iterative_lock: return self
-        try:
-          self.__oldjobinfo = self.runningjobinfo(exceptions=True)
-        except (IOError, OSError) as e:
-          self.__oldjobinfo = e
+      try:
+        with JobLock(self.iterative_lock_filename, **self.sublockkwargs) as iterative_lock:
+          self.__iterative_lock = iterative_lock
+          if not iterative_lock: return self
           try:
-            self.__open()
-          except FileExistsError:
-            return self
-        except ValueError as e:
-          self.__oldjobinfo = e
-          if self.corruptfiletimeout is not None:
+            self.__oldjobinfo = self.runningjobinfo(exceptions=True)
+          except (IOError, OSError) as e:
+            self.__oldjobinfo = e
+            try:
+              self.__open()
+            except FileExistsError:
+              return self
+          except ValueError as e:
+            self.__oldjobinfo = e
             modified = datetime.datetime.fromtimestamp(self.filename.stat().st_mtime)
             now = datetime.datetime.now()
-            if now - modified >= self.corruptfiletimeout:
+            age = now - modified
+            if self.corruptfiletimeout is not None and age >= self.corruptfiletimeout:
+              for outputfile in self.outputfiles:
+                rm_missing_ok(outputfile)
+              rm_missing_ok(self.filename)
+              self.removed_failed_job = True
+              try:
+                self.__open()
+              except FileExistsError:
+                return self
+            else:
+              if age >= datetime.timedelta(seconds=1):
+                logger.warning(f"{self.filename} is likely corrupt (age {age}), consider setting a corrupt file timeout to remove it")
+              return self
+          else:
+            if jobfinished(*self.oldjobinfo, dojoblist=self.dosqueue, cachejoblist=self.cachesqueue):
               for outputfile in self.outputfiles:
                 rm_missing_ok(outputfile)
               rm_missing_ok(self.filename)
@@ -399,20 +412,8 @@ class JobLock(object):
                 return self
             else:
               return self
-          else:
-            return self
-        else:
-          if jobfinished(*self.oldjobinfo, dojoblist=self.dosqueue, cachejoblist=self.cachesqueue):
-            for outputfile in self.outputfiles:
-              rm_missing_ok(outputfile)
-            rm_missing_ok(self.filename)
-            self.removed_failed_job = True
-            try:
-              self.__open()
-            except FileExistsError:
-              return self
-          else:
-            return self
+      except RecursionError:
+        return self
     except FileNotFoundError:
       if self.suppressfileopenfailure and self.filename.parent.exists():
         return self
@@ -601,3 +602,28 @@ class MultiJobLock(contextlib.ExitStack):
         self.close()
         return False
     return True
+
+def add_job_lock_arguments(argumentparser):
+  p = argumentparser
+  g = p.add_mutually_exclusive_group()
+  g.add_argument("--squeue-output", help="output of 'squeue --Format jobid,state --noheader'")
+  g.add_argument("--squeue-output-file", type=pathlib.Path, help="file containing the output of 'squeue --Format jobid,state --noheader'")
+  g = p.add_mutually_exclusive_group()
+  g.add_argument("--condorq-output", help="output of 'condor_q -nobatch'")
+  g.add_argument("--condorq-output-file", type=pathlib.Path, help="file containing the output of 'condor_q -nobatch'")
+
+  def parsetimedelta(s):
+    regex = r"(?P<hours>\d+):(?P<minutes>\d+):(?P<seconds>\d+(?:\.\d*)?)$"
+    match = re.match(regex, s)
+    if match is None:
+      raise ValueError(f"{s} does not match {regex}")
+    return datetime.timedelta(hours=int(match.group("hours")), minutes=int(match.group("minutes")), seconds=float(match.group("seconds")))
+  p.add_argument("--corrupt-job-lock-timeout", type=parsetimedelta, help="delete corrupt joblock files after this long (%H:%M:%S, default 1:0:0)")
+
+def process_job_lock_arguments(parsed_args):
+  dct = parsed_args.__dict__
+  setsqueueoutput(output=dct.pop("squeue_output"), filename=dct.pop("squeue_output_file"))
+  setcondorqoutput(output=dct.pop("condorq_output"), filename=dct.pop("condorq_output_file"))
+
+  timeout = dct.pop("corrupt_job_lock_timeout")
+  JobLock.setdefaultcorruptfiletimeout(timeout)
